ui
==

This package defines the interface to the computational backend
`ComPWA <https://compwa.github.io/ComPWA/>`_. These bindings have been defined
with `pybind11 <https://pybind11.readthedocs.io/>`_.

Module contents
---------------

.. automodule:: pycompwa.ui
   :members:
   :undoc-members:
   :show-inheritance:
